Module: Assignment::Attributes
- Defined in:
- lib/assignment/attributes.rb
Instance Method Summary collapse
-
#assign_attributes(new_attributes) ⇒ Object
Allows you to set all the attributes by passing in a hash of attributes with keys matching the attribute names.
Instance Method Details
#assign_attributes(new_attributes) ⇒ Object
Allows you to set all the attributes by passing in a hash of attributes with keys matching the attribute names.
class Cat
include Assignment::Attributes
attr_accessor :name, :status
end
cat = Cat.new
cat.assign_attributes(name: "Gorby", status: "yawning")
cat.name # => 'Gorby'
cat.status => 'yawning'
cat.assign_attributes(status: "sleeping")
cat.name # => 'Gorby'
cat.status => 'sleeping'
21 22 23 24 25 26 27 28 29 |
# File 'lib/assignment/attributes.rb', line 21 def assign_attributes(new_attributes) if !new_attributes.respond_to?(:stringify_keys) raise ArgumentError, "When assigning attributes, you must pass a hash as an argument." end return if new_attributes.nil? || new_attributes.empty? attributes = new_attributes.stringify_keys _assign_attributes(attributes) end |